@@ -23,8 +23,8 @@
 #define KHC_APPLICATION_H
 
 #include <QApplication>
-#include <QUrl>
 #include <QCommandLineParser>
+#include <QUrl>
 
 namespace KHC {
 
@@ -38,7 +38,7 @@ namespace KHC {
 
       QCommandLineParser *cmdParser();
 
-    public slots:
+    public Q_SLOTS:
         void activate(const QStringList& args, const QString &workingDirectory);
 
     private:
