@@ -21,7 +21,8 @@
 #define KHC_PLUGINTRAVERSER_H
 
 #include "docentrytraverser.h"
-#include <QtGlobal>
+#include <QTreeWidget>
+
 class QTreeWidget;
 
 namespace KHC {
@@ -35,9 +36,9 @@ namespace KHC {
       PluginTraverser( Navigator *navigator, QTreeWidget *parent );
       PluginTraverser( Navigator *navigator, NavigatorItem *parent );
 
-      void process( DocEntry *entry ) Q_DECL_OVERRIDE;
+      void process( DocEntry *entry ) override;
 
-      DocEntryTraverser *createChild( DocEntry *entry ) Q_DECL_OVERRIDE;
+      DocEntryTraverser *createChild( DocEntry *entry ) override;
 
   private:
     QTreeWidget *mListView;
