@@ -1,8 +1,26 @@
 
+/*
+    This file is part of KHelpCenter.
+
+    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 #include "searchengine.h"
 
-#include <QMessageBox>
-
 #include "docmetainfo.h"
 #include "view.h"
 #include "searchhandler.h"
@@ -18,25 +36,25 @@ SearchTraverser::SearchTraverser( SearchEngine *engine, int level ) :
   mMaxLevel( 999 ), mEngine( engine), mLevel( level ), mResultsPtr( &mResults )
 {
 #if 0
-  khcDebug() << "SearchTraverser():" << mLevel << this;
+  qCDebug(KHC_LOG) << "SearchTraverser():" << mLevel << this;
 #endif
 }
 
 SearchTraverser::~SearchTraverser()
 {
 #if 0
-    khcDebug() << "~SearchTraverser():" << mLevel << this;
+    qCDebug(KHC_LOG) << "~SearchTraverser():" << mLevel << this;
 #endif
 }
 
 void SearchTraverser::process( DocEntry * )
 {
-  khcDebug() << "SearchTraverser::process()";
+  qCDebug(KHC_LOG) << "SearchTraverser::process()";
 }
 
 void SearchTraverser::startProcess( DocEntry *entry )
 {
-//  khcDebug() << "SearchTraverser::startProcess():" << entry->name()
+//  qCDebug(KHC_LOG) << "SearchTraverser::startProcess():" << entry->name()
 //    << "SEARCH:" << entry->search();
 
   if ( !mEngine->canSearch( entry ) || !entry->searchEnabled() ) {
@@ -44,7 +62,7 @@ void SearchTraverser::startProcess( DocEntry *entry )
     return;
   }
 
-//  khcDebug() << "SearchTraverser::startProcess():" << entry->identifier();
+//  qCDebug(KHC_LOG) << "SearchTraverser::startProcess():" << entry->identifier();
 
   SearchHandler *handler = mEngine->handler( entry->documentType() );
 
@@ -65,7 +83,7 @@ void SearchTraverser::startProcess( DocEntry *entry )
   handler->search( entry, mEngine->words(), mEngine->maxResults(),
     mEngine->operation() );
 
-//  khcDebug() << "SearchTraverser::startProcess() done: " << entry->name();
+//  qCDebug(KHC_LOG) << "SearchTraverser::startProcess() done: " << entry->name();
 }
 
 void SearchTraverser::connectHandler( SearchHandler *handler )
@@ -75,10 +93,8 @@ void SearchTraverser::connectHandler( SearchHandler *handler )
   int count = 0;
   if ( it != mConnectCount.end() ) count = *it;
   if ( count == 0 ) {
-    connect( handler, SIGNAL( searchError( SearchHandler *, DocEntry *, const QString & ) ),
-      SLOT( showSearchError( SearchHandler *, DocEntry *, const QString & ) ) );
-    connect( handler, SIGNAL( searchFinished( SearchHandler *, DocEntry *, const QString & ) ),
-      SLOT( showSearchResult( SearchHandler *, DocEntry *, const QString & ) ) );
+    connect(handler, &SearchHandler::searchError, this, &SearchTraverser::showSearchError);
+    connect(handler, &SearchHandler::searchFinished, this, &SearchTraverser::showSearchResult);
   }
   mConnectCount[ handler ] = ++count;
 }
@@ -88,15 +104,13 @@ void SearchTraverser::disconnectHandler( SearchHandler *handler )
   QMap<SearchHandler *,int>::Iterator it;
   it = mConnectCount.find( handler );
   if ( it == mConnectCount.end() ) {
-    khcWarning() << "SearchTraverser::disconnectHandler() handler not connected.";
+    qCWarning(KHC_LOG) << "SearchTraverser::disconnectHandler() handler not connected.";
   } else {
     int count = *it;
     --count;
     if ( count == 0 ) {
-      disconnect( handler, SIGNAL( searchError( SearchHandler *, DocEntry *, const QString & ) ),
-        this, SLOT( showSearchError( SearchHandler *, DocEntry *, const QString & ) ) );
-      disconnect( handler, SIGNAL( searchFinished( SearchHandler *, DocEntry *, const QString & ) ),
-        this, SLOT( showSearchResult( SearchHandler *, DocEntry *, const QString & ) ) );
+      disconnect( handler, &SearchHandler::searchError, this, &SearchTraverser::showSearchError );
+      disconnect( handler, &SearchHandler::searchFinished, this, &SearchTraverser::showSearchResult );
     }
     mConnectCount[ handler ] = count;
   }
@@ -104,7 +118,7 @@ void SearchTraverser::disconnectHandler( SearchHandler *handler )
 
 DocEntryTraverser *SearchTraverser::createChild( DocEntry *parentEntry )
 {
-//  khcDebug() << "SearchTraverser::createChild() level " << mLevel;
+//  qCDebug(KHC_LOG) << "SearchTraverser::createChild() level " << mLevel;
 
   if ( mLevel >= mMaxLevel ) {
     ++mLevel;
@@ -119,7 +133,7 @@ DocEntryTraverser *SearchTraverser::createChild( DocEntry *parentEntry )
 
 DocEntryTraverser *SearchTraverser::parentTraverser()
 {
-//  khcDebug() << "SearchTraverser::parentTraverser(): level: " << mLevel;
+//  qCDebug(KHC_LOG) << "SearchTraverser::parentTraverser(): level: " << mLevel;
 
   if ( mLevel > mMaxLevel ) {
     return this;
@@ -130,7 +144,7 @@ DocEntryTraverser *SearchTraverser::parentTraverser()
 
 void SearchTraverser::deleteTraverser()
 {
-//  khcDebug() << "SearchTraverser::deleteTraverser()";
+//  qCDebug(KHC_LOG) << "SearchTraverser::deleteTraverser()";
 
   if ( mLevel > mMaxLevel ) {
     --mLevel;
@@ -141,7 +155,7 @@ void SearchTraverser::deleteTraverser()
 
 void SearchTraverser::showSearchError( SearchHandler *handler, DocEntry *entry, const QString &error )
 {
-//  khcDebug() << "SearchTraverser::showSearchError():" << entry->name();
+//  qCDebug(KHC_LOG) << "SearchTraverser::showSearchError():" << entry->name();
 
   mResultsPtr->append( qMakePair( entry, error ) );
 
@@ -154,7 +168,7 @@ void SearchTraverser::showSearchError( SearchHandler *handler, DocEntry *entry,
 
 void SearchTraverser::showSearchResult( SearchHandler *handler, DocEntry *entry, const QString &result )
 {
-//  khcDebug() << "SearchTraverser::showSearchResult():" << entry->name();
+//  qCDebug(KHC_LOG) << "SearchTraverser::showSearchResult():" << entry->name();
 
   mResultsPtr->append( qMakePair( entry, result ) );
 
@@ -165,7 +179,7 @@ void SearchTraverser::showSearchResult( SearchHandler *handler, DocEntry *entry,
 
 void SearchTraverser::finishTraversal()
 {
-//  khcDebug() << "SearchTraverser::finishTraversal()";
+//  qCDebug(KHC_LOG) << "SearchTraverser::finishTraversal()";
 
   mEngine->view()->beginSearchResult();
   mEngine->view()->writeSearchResult( mEngine->grantleeFormatter()->formatSearchResults( mWords, mResults ) );
@@ -183,7 +197,7 @@ void SearchTraverser::setWords( const QString &words )
 SearchEngine::SearchEngine( View *destination )
   : QObject(),
     mSearchRunning( false ), mView( destination ),
-    mRootTraverser( 0 )
+    mRootTraverser( nullptr )
 {
 }
 
@@ -194,11 +208,11 @@ SearchEngine::~SearchEngine()
 
 bool SearchEngine::initSearchHandlers()
 {
-  const QStringList resourceDirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, "searchhandlers/", QStandardPaths::LocateDirectory );
+  const QStringList resourceDirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("searchhandlers/"), QStandardPaths::LocateDirectory );
   QStringList resources;
   foreach(const QString& dir, resourceDirs) {
       QDir d(dir);
-    foreach ( const QString& entry, d.entryList( QStringList( "*.desktop" ), QDir::Files ) ) {
+    foreach ( const QString& entry, d.entryList( QStringList( QStringLiteral("*.desktop") ), QDir::Files ) ) {
       resources += dir + entry;
     }
   }
@@ -206,10 +220,10 @@ bool SearchEngine::initSearchHandlers()
   QStringList::ConstIterator it;
   for( it = resources.constBegin(); it != resources.constEnd(); ++it ) {
     QString filename = *it;
-    khcDebug() << "SearchEngine::initSearchHandlers(): " << filename;
+    qCDebug(KHC_LOG) << "SearchEngine::initSearchHandlers(): " << filename;
     QSharedPointer<SearchHandler> handler( SearchHandler::initFromFile( filename ) );
     if ( !handler ) {
-     QMessageBox::warning( mView->widget(), i18n("Handler"), i18n("Unable to initialize SearchHandler from file '%1'.", filename ) );
+      qCWarning(KHC_LOG) << "Unable to initialize SearchHandler from" << filename;
     } else {
       QStringList documentTypes = handler->documentTypes();
       QStringList::ConstIterator it;
@@ -227,7 +241,7 @@ bool SearchEngine::initSearchHandlers()
 
   if ( mHandlers.isEmpty() ) {
     QString txt = i18n("No valid search handler found.");
-    khcWarning() << txt;
+    qCWarning(KHC_LOG) << txt;
 //    KMessageBox::sorry( mView->widget(), txt );
     return false;
   }
@@ -247,9 +261,9 @@ bool SearchEngine::search( const QString & words, const QString & method, int ma
   mScope = scope;
 
   // Saner variables to store search parameters:
-  mWordList = words.split(' ');
+  mWordList = words.split(QLatin1Char(' '));
   mMaxResults = matches;
-  if ( method == "or" ) mOperation = Or;
+  if ( method == QLatin1String("or") ) mOperation = Or;
   else mOperation = And;
 
   if ( !mView ) {
@@ -258,10 +272,10 @@ bool SearchEngine::search( const QString & words, const QString & method, int ma
 
   QString txt = i18n("Search Results for '%1':", words.toHtmlEscaped() );
 
-  mStderr = "<b>" + txt + "</b>\n";
+  mStderr = QStringLiteral("<b>") + txt + QStringLiteral("</b>\n");
 
   if ( mRootTraverser ) {
-    khcDebug() << "SearchEngine::search(): mRootTraverser not null.";
+    qCDebug(KHC_LOG) << "SearchEngine::search(): mRootTraverser not null.";
     return false;
   }
   mRootTraverser = new SearchTraverser( this, 0 );
@@ -277,7 +291,7 @@ QString SearchEngine::substituteSearchQuery( const QString &query,
 {
   QString result = query;
   result.replace( QLatin1String("%i"), identifier );
-  result.replace( QLatin1String("%w"), words.join( "+" ) );
+  result.replace( QLatin1String("%w"), words.join( QLatin1Char('+') ) );
   result.replace( QLatin1String("%m"), QString::number( maxResults ) );
   QString o = QLatin1String(operation == Or ? "or" : "and");
   result.replace( QLatin1String("%o"), o );
@@ -301,7 +315,7 @@ View *SearchEngine::view() const
 void SearchEngine::finishSearch()
 {
   delete mRootTraverser;
-  mRootTraverser = 0;
+  mRootTraverser = nullptr;
   mSearchRunning = false;
 
   emit searchFinished();
@@ -325,7 +339,7 @@ bool SearchEngine::isRunning() const
 SearchHandler *SearchEngine::handler( const QString &documentType ) const
 {
   QSharedPointer<SearchHandler> ptr = mHandlers.value( documentType );
-  return ptr ? ptr.data() : 0;
+  return ptr ? ptr.data() : nullptr;
 }
 
 QStringList SearchEngine::words() const
