@@ -25,7 +25,6 @@
 #include "searchengine.h"
 
 #include <QObject>
-
 #include <QProcess>
 
 class KConfigGroup;
@@ -40,7 +39,7 @@ namespace KHC {
   class SearchJob : public QObject {
       Q_OBJECT
     public:
-      SearchJob(DocEntry *entry);
+      explicit SearchJob(DocEntry *entry);
       ~SearchJob();
 
       bool startLocal(const QString &cmdString);
@@ -97,20 +96,20 @@ namespace KHC {
   {
       Q_OBJECT
     public:
-      ExternalProcessSearchHandler( const KConfigGroup &cg );
+      explicit ExternalProcessSearchHandler( const KConfigGroup &cg );
 
       void search( DocEntry *, const QStringList &words,
 	int maxResults = 10,
-	SearchEngine::Operation operation = SearchEngine::And ) Q_DECL_OVERRIDE;
+	SearchEngine::Operation operation = SearchEngine::And ) override;
 
-      QString indexCommand( const QString &identifier ) const Q_DECL_OVERRIDE;
+      QString indexCommand( const QString &identifier ) const override;
 
-      bool checkPaths(QString* error) const Q_DECL_OVERRIDE;
+      bool checkPaths(QString* error) const override;
 
     private:
       bool checkBinary( const QString &cmd ) const;
 
-    private slots:
+    private Q_SLOTS:
       void slotSearchFinished( SearchJob *, DocEntry *, const QString & );
       void slotSearchError( SearchJob *, DocEntry *, const QString & );
 
